@@ -57,7 +57,7 @@ def mTimeVersion(init_file):
     return d.strftime("%Y.%m.%d")
 
 
-def getVersionFromArchiveId(git_archive_id='1646575761  (HEAD -> master, tag: v3.5.0)'):
+def getVersionFromArchiveId(git_archive_id='1670154335  (HEAD -> master, tag: v3.7.0)'):
     """ Extract the tag if a source is from git archive.
 
         When source is exported via `git archive`, the git_archive_id init value is modified
@@ -69,7 +69,7 @@ def getVersionFromArchiveId(git_archive_id='1646575761  (HEAD -> master, tag: v3
         See man gitattributes(5) and git-log(1) (PRETTY FORMATS) for more details.
     """
     # mangle the magic string to make sure it is not replaced by git archive
-    if not git_archive_id.startswith('$For''mat:'):
+    if not git_archive_id.startswith('$For' + 'mat:'):
         # source was modified by git archive, try to parse the version from
         # the value of git_archive_id
 
