@@ -14,16 +14,16 @@
 # Copyright Buildbot Team Members
 
 from datetime import datetime
-from fnmatch import fnmatch
 
 from twisted.internet import defer
+from twisted.logger import Logger
 
 from buildbot import config
 from buildbot.changes import base
 from buildbot.util import bytes2unicode
 from buildbot.util import datetime2epoch
 from buildbot.util import httpclientservice
-from buildbot.util.logger import Logger
+from buildbot.util.pullrequest import PullRequestMixin
 from buildbot.util.state import StateMixin
 
 log = Logger()
@@ -37,27 +37,12 @@ link_urls = {
 }
 
 
-class PullRequestMixin:
-    def extractProperties(self, payload):
-        def flatten(properties, base, info_dict):
-            for k, v in info_dict.items():
-                name = ".".join([base, k])
-                if isinstance(v, dict):
-                    flatten(properties, name, v)
-                elif any([fnmatch(name, expr)
-                          for expr in self.github_property_whitelist]):
-                    properties[name] = v
-
-        properties = {}
-        flatten(properties, "github", payload)
-        return properties
-
-
 class GitHubPullrequestPoller(base.ReconfigurablePollingChangeSource,
                               StateMixin, PullRequestMixin):
     compare_attrs = ("owner", "repo", "token", "branches", "pollInterval",
                      "category", "pollAtLaunch", "name")
     db_class_name = 'GitHubPullrequestPoller'
+    property_basename = "github"
 
     def __init__(self, owner, repo, **kwargs):
         name = kwargs.get("name")
@@ -106,8 +91,12 @@ class GitHubPullrequestPoller(base.ReconfigurablePollingChangeSource,
 
         http_headers = {'User-Agent': 'Buildbot'}
         if token is not None:
+            token = yield self.renderSecrets(token)
             http_headers.update({'Authorization': 'token ' + token})
 
+        if github_property_whitelist is None:
+            github_property_whitelist = []
+
         self._http = yield httpclientservice.HTTPClientService.getService(
             self.master, baseURL, headers=http_headers)
 
@@ -115,14 +104,11 @@ class GitHubPullrequestPoller(base.ReconfigurablePollingChangeSource,
         self.owner = owner
         self.repo = repo
         self.branches = branches
-        self.github_property_whitelist = github_property_whitelist
         self.pollInterval = pollInterval
         self.pollAtLaunch = pollAtLaunch
         self.repository_type = link_urls[repository_type]
         self.magic_link = magic_link
-
-        if github_property_whitelist is None:
-            self.github_property_whitelist = []
+        self.external_property_whitelist = github_property_whitelist
 
         if callable(pullrequest_filter):
             self.pullrequest_filter = pullrequest_filter
@@ -134,7 +120,7 @@ class GitHubPullrequestPoller(base.ReconfigurablePollingChangeSource,
 
     def describe(self):
         return ("GitHubPullrequestPoller watching the "
-                "GitHub repository {}/{}").format(self.owner, self.repo)
+                f"GitHub repository {self.owner}/{self.repo}")
 
     @defer.inlineCallbacks
     def _getPullInformation(self, pull_number):
@@ -145,16 +131,15 @@ class GitHubPullrequestPoller(base.ReconfigurablePollingChangeSource,
 
     @defer.inlineCallbacks
     def _getPulls(self):
-        log.debug(("GitHubPullrequestPoller: polling "
-                   "GitHub repository {}/{}, branches: {}").format(self.owner, self.repo,
-                                                                   self.branches))
+        log.debug("GitHubPullrequestPoller: polling "
+                  f"GitHub repository {self.owner}/{self.repo}, branches: {self.branches}")
         result = yield self._http.get('/'.join(
             ['/repos', self.owner, self.repo, 'pulls']))
         my_json = yield result.json()
         if result.code != 200:
             message = my_json.get('message', 'unknown')
-            log.error("GitHubPullrequestPoller error {0.code} '{1}' "
-                      "while loading {0.url}".format(result, message))
+            log.error(f"GitHubPullrequestPoller error {result.code} '{message}' "
+                      f"while loading {result.url}")
             return []
         return my_json
 
@@ -191,8 +176,7 @@ class GitHubPullrequestPoller(base.ReconfigurablePollingChangeSource,
         # Get currently assigned revision of PR number
 
         result = yield self._getStateObjectId()
-        rev = yield self.master.db.state.getState(result, 'pull_request%d' %
-                                                  prnumber, None)
+        rev = yield self.master.db.state.getState(result, f'pull_request{prnumber}', None)
         return rev
 
     @defer.inlineCallbacks
@@ -200,13 +184,12 @@ class GitHubPullrequestPoller(base.ReconfigurablePollingChangeSource,
         # Set the updated revision for PR number.
 
         result = yield self._getStateObjectId()
-        yield self.master.db.state.setState(result,
-                                            'pull_request%d' % prnumber, rev)
+        yield self.master.db.state.setState(result, f'pull_request{prnumber}', rev)
 
     @defer.inlineCallbacks
     def _getStateObjectId(self):
         # Return a deferred for object id in state db.
-        result = yield self.master.db.state.getObjectId('{}/{}'.format(self.owner, self.repo),
+        result = yield self.master.db.state.getObjectId(f'{self.owner}/{self.repo}',
                                                         self.db_class_name)
         return result
 
@@ -230,7 +213,7 @@ class GitHubPullrequestPoller(base.ReconfigurablePollingChangeSource,
                 pr = yield self._getPullInformation(prnumber)
                 title = pr['title']
                 if self.magic_link:
-                    branch = 'refs/pull/{:d}/merge'.format(prnumber)
+                    branch = f'refs/pull/{prnumber}/merge'
                     repo = pr['base']['repo'][self.repository_type]
                 else:
                     branch = pr['head']['ref']
@@ -255,34 +238,33 @@ class GitHubPullrequestPoller(base.ReconfigurablePollingChangeSource,
                 if failures:
                     for failure in failures:
                         log.error("while processing changes for "
-                                  "Pullrequest {} revision {}".format(
-                                      prnumber, revision))
-                        # Fail on the first error!
-                        failures[0].raiseException()
+                                  f"Pullrequest {prnumber} revision {revision}: {failure}")
+                    # Fail on the first error!
+                    failures[0].raiseException()
                 [authors, committers, files] = [r[1] for r in results]
 
                 author = authors[0][0] + " <" + authors[0][1] + ">"
 
                 committer = committers[0][0] + " <" + committers[0][1] + ">"
 
-                properties = self.extractProperties(pr)
-
                 # emit the change
                 yield self.master.data.updates.addChange(
                     author=author,
                     committer=committer,
                     revision=bytes2unicode(revision),
                     revlink=bytes2unicode(revlink),
-                    comments='GitHub Pull Request #{0} ({1} commit{2})\n{3}\n{4}'.
-                    format(prnumber, commits, 's'
-                           if commits > 0 else '', title, comments),
+                    comments=f"GitHub Pull Request #{prnumber} "
+                             f"({commits} commit{'s' if commits > 0 else ''})\n{title}\n{comments}",
                     when_timestamp=datetime2epoch(updated),
                     branch=bytes2unicode(branch),
                     category=self.category,
                     project=project,
                     repository=bytes2unicode(repo),
                     files=files,
-                    properties=properties,
+                    properties={
+                        'pullrequesturl': revlink,
+                        **self.extractProperties(pr),
+                    },
                     src='git')
 
     @defer.inlineCallbacks
