@@ -173,9 +173,9 @@ class ChangesConnectorComponent(base.DBConnectorComponent):
         assert buildid > 0
 
         gssfb = self.master.db.sourcestamps.getSourceStampsForBuild
-        changes = list()
+        changes = []
         currentBuild = yield self.master.db.builds.getBuild(buildid)
-        fromChanges, toChanges = dict(), dict()
+        fromChanges, toChanges = {}, {}
         ssBuild = yield gssfb(buildid)
         for ss in ssBuild:
             fromChanges[ss['codebase']] = yield self.getChangeFromSSid(ss['ssid'])
