@@ -49,6 +49,11 @@ class UpgradeFromBefore3p0Error(Exception):
 
 
 class Model(base.DBConnectorComponent):
+
+    property_name_length = 256
+    property_source_length = 256
+    hash_length = 40
+
     #
     # schema
     #
@@ -131,10 +136,10 @@ class Model(base.DBConnectorComponent):
         sa.Column('buildid', sa.Integer,
                   sa.ForeignKey('builds.id', ondelete='CASCADE'),
                   nullable=False),
-        sa.Column('name', sa.String(256), nullable=False),
+        sa.Column('name', sa.String(property_name_length), nullable=False),
         # JSON encoded value
         sa.Column('value', sa.Text, nullable=False),
-        sa.Column('source', sa.String(256), nullable=False),
+        sa.Column('source', sa.String(property_source_length), nullable=False),
     )
 
     # This table contains transient build state.
@@ -246,7 +251,7 @@ class Model(base.DBConnectorComponent):
         sa.Column('buildsetid', sa.Integer,
                   sa.ForeignKey('buildsets.id', ondelete='CASCADE'),
                   nullable=False),
-        sa.Column('property_name', sa.String(256), nullable=False),
+        sa.Column('property_name', sa.String(property_name_length), nullable=False),
         # JSON-encoded tuple of (value, source)
         sa.Column('property_value', sa.Text, nullable=False),
     )
@@ -298,7 +303,7 @@ class Model(base.DBConnectorComponent):
         # name for this changesource, as given in the configuration, plus a hash
         # of that name used for a unique index
         sa.Column('name', sa.Text, nullable=False),
-        sa.Column('name_hash', sa.String(40), nullable=False),
+        sa.Column('name_hash', sa.String(hash_length), nullable=False),
     )
 
     # This links changesources to the master where they are running.  A changesource
@@ -371,7 +376,7 @@ class Model(base.DBConnectorComponent):
         sa.Column('changeid', sa.Integer,
                   sa.ForeignKey('changes.changeid', ondelete='CASCADE'),
                   nullable=False),
-        sa.Column('property_name', sa.String(256), nullable=False),
+        sa.Column('property_name', sa.String(property_name_length), nullable=False),
         # JSON-encoded tuple of (value, source)
         sa.Column('property_value', sa.Text, nullable=False),
     )
@@ -484,7 +489,7 @@ class Model(base.DBConnectorComponent):
 
         # hash of the branch, revision, patchid, repository, codebase, and
         # project, using hashColumns.
-        sa.Column('ss_hash', sa.String(40), nullable=False),
+        sa.Column('ss_hash', sa.String(hash_length), nullable=False),
 
         # the branch to check out.  When branch is NULL, that means
         # the main branch (trunk, master, etc.)
@@ -540,7 +545,7 @@ class Model(base.DBConnectorComponent):
         # name for this scheduler, as given in the configuration, plus a hash
         # of that name used for a unique index
         sa.Column('name', sa.Text, nullable=False),
-        sa.Column('name_hash', sa.String(40), nullable=False),
+        sa.Column('name_hash', sa.String(hash_length), nullable=False),
         sa.Column('enabled', sa.SmallInteger,
                   server_default=sa.DefaultClause("1")),
     )
@@ -589,7 +594,7 @@ class Model(base.DBConnectorComponent):
         # builder's description
         sa.Column('description', sa.Text, nullable=True),
         # sha1 of name; used for a unique index
-        sa.Column('name_hash', sa.String(40), nullable=False),
+        sa.Column('name_hash', sa.String(hash_length), nullable=False),
     )
 
     # This links builders to the master where they are running.  A builder
@@ -615,7 +620,7 @@ class Model(base.DBConnectorComponent):
         # tag's name
         sa.Column('name', sa.Text, nullable=False),
         # sha1 of name; used for a unique index
-        sa.Column('name_hash', sa.String(40), nullable=False),
+        sa.Column('name_hash', sa.String(hash_length), nullable=False),
     )
 
     # a many-to-may relationship between builders and tags
@@ -821,7 +826,7 @@ class Model(base.DBConnectorComponent):
         # master's name (generally in the form hostname:basedir)
         sa.Column('name', sa.Text, nullable=False),
         # sha1 of name; used for a unique index
-        sa.Column('name_hash', sa.String(40), nullable=False),
+        sa.Column('name_hash', sa.String(hash_length), nullable=False),
 
         # true if this master is running
         sa.Column('active', sa.Integer, nullable=False),
