@@ -21,7 +21,6 @@ from twisted.internet import error
 from twisted.python import failure
 from twisted.python import log
 from twisted.python.failure import Failure
-from zope.interface import implementer
 
 from buildbot import interfaces
 from buildbot.process import buildstep
@@ -37,11 +36,11 @@ from buildbot.process.results import computeResultAndTermination
 from buildbot.process.results import statusToString
 from buildbot.process.results import worst_status
 from buildbot.reporters.utils import getURLForBuild
+from buildbot.util import Notifier
 from buildbot.util import bytes2unicode
 from buildbot.util.eventual import eventually
 
 
-@implementer(interfaces.IBuildControl)
 class Build(properties.PropertiesMixin):
 
     """I represent a single build by a single worker. Specialized Builders can
@@ -53,24 +52,18 @@ class Build(properties.PropertiesMixin):
     L{buildbot.process.step.BuildStep} objects. Each step is a single remote
     command, possibly a shell command.
 
-    During the build, I put status information into my C{BuildStatus}
-    gatherer.
-
     After the build, I go away.
 
     I can be used by a factory by setting buildClass on
     L{buildbot.process.factory.BuildFactory}
 
     @ivar requests: the list of L{BuildRequest}s that triggered me
-    @ivar build_status: the L{buildbot.status.build.BuildStatus} that
-                        collects our status
     """
 
     VIRTUAL_BUILDERNAME_PROP = "virtual_builder_name"
     VIRTUAL_BUILDERDESCRIPTION_PROP = "virtual_builder_description"
     VIRTUAL_BUILDERTAGS_PROP = "virtual_builder_tags"
     workdir = "build"
-    build_status = None
     reason = "changes"
     finished = False
     results = None
@@ -78,7 +71,10 @@ class Build(properties.PropertiesMixin):
     set_runtime_properties = True
     subs = None
 
-    _sentinel = []  # used as a sentinel to indicate unspecified initial_value
+    class Sentinel:
+        pass
+
+    _sentinel = Sentinel()  # used as a sentinel to indicate unspecified initial_value
 
     def __init__(self, requests):
         self.requests = requests
@@ -90,6 +86,7 @@ class Build(properties.PropertiesMixin):
         self.currentStep = None
         self.workerEnvironment = {}
         self.buildid = None
+        self._buildid_notifier = Notifier()
         self.number = None
         self.executedSteps = []
         self.stepnames = {}
@@ -101,6 +98,7 @@ class Build(properties.PropertiesMixin):
         # overall results, may downgrade after each step
         self.results = SUCCESS
         self.properties = properties.Properties()
+        self.stopped_reason = None
 
         # tracks execution during the build finish phase
         self._locks_released = False
@@ -163,8 +161,8 @@ class Build(properties.PropertiesMixin):
         return files
 
     def __repr__(self):
-        return "<Build {} number:{} results:{}>".format(self.builder.name, repr(self.number),
-                                                        statusToString(self.results))
+        return (f"<Build {self.builder.name} number:{repr(self.number)} "
+                f"results:{statusToString(self.results)}>")
 
     def blamelist(self):
         # Note that this algorithm is also implemented in
@@ -203,11 +201,11 @@ class Build(properties.PropertiesMixin):
         return self.workerforbuilder.getWorkerCommandVersion(command, oldversion)
 
     def getWorkerName(self):
-        return self.workerforbuilder.worker.workername
+        return self.workername
 
     @staticmethod
     def setupPropertiesKnownBeforeBuildStarts(props, requests, builder,
-                                              workerforbuilder):
+                                              workerforbuilder=None):
         # Note that this function does not setup the 'builddir' worker property
         # It's not possible to know it until before the actual worker has
         # attached.
@@ -231,17 +229,21 @@ class Build(properties.PropertiesMixin):
         # get worker properties
         # navigate our way back to the L{buildbot.worker.Worker}
         # object that came from the config, and get its properties
-        workerforbuilder.worker.setupProperties(props)
+        if workerforbuilder is not None:
+            workerforbuilder.worker.setupProperties(props)
 
-    def setupOwnProperties(self):
+    @staticmethod
+    def setupBuildProperties(props, requests, sources=None, number=None):
         # now set some properties of our own, corresponding to the
         # build itself
-        props = self.getProperties()
-        props.setProperty("buildnumber", self.number, "Build")
+        props.setProperty("buildnumber", number, "Build")
 
-        if self.sources and len(self.sources) == 1:
+        if sources is None:
+            sources = requests[0].mergeSourceStampsWith(requests[1:])
+
+        if sources and len(sources) == 1:
             # old interface for backwards compatibility
-            source = self.sources[0]
+            source = sources[0]
             props.setProperty("branch", source.branch, "Build")
             props.setProperty("revision", source.revision, "Build")
             props.setProperty("repository", source.repository, "Build")
@@ -262,7 +264,7 @@ class Build(properties.PropertiesMixin):
     def setupWorkerForBuilder(self, workerforbuilder):
         self.path_module = workerforbuilder.worker.path_module
         self.workername = workerforbuilder.worker.workername
-        self.build_status.setWorkername(self.workername)
+        self.worker_info = workerforbuilder.worker.info
 
     @defer.inlineCallbacks
     def getBuilderId(self):
@@ -288,7 +290,7 @@ class Build(properties.PropertiesMixin):
         return self._builderid
 
     @defer.inlineCallbacks
-    def startBuild(self, build_status, workerforbuilder):
+    def startBuild(self, workerforbuilder):
         """This method sets up the build, then starts it by invoking the
         first Step. It returns a Deferred which will fire when the build
         finishes. This Deferred is guaranteed to never errback."""
@@ -297,9 +299,13 @@ class Build(properties.PropertiesMixin):
 
         worker = workerforbuilder.worker
 
-        log.msg("{}.startBuild".format(self))
+        # Cache the worker information as variables instead of accessing via worker, as the worker
+        # will disappear during disconnection and some of these properties may still be needed.
+        self.workername = worker.workername
+        self.worker_info = worker.info
+
+        log.msg(f"{self}.startBuild")
 
-        self.build_status = build_status
         # TODO: this will go away when build collapsing is implemented; until
         # then we just assign the build to the first buildrequest
         brid = self.requests[0].id
@@ -309,6 +315,7 @@ class Build(properties.PropertiesMixin):
                 builderid=builderid,
                 buildrequestid=brid,
                 workerid=worker.workerid)
+        self._buildid_notifier.notify(self.buildid)
 
         self.stopBuildConsumer = yield self.master.mq.startConsuming(self.controlStopBuild,
                                                                      ("control", "builds",
@@ -321,10 +328,11 @@ class Build(properties.PropertiesMixin):
         self.preparation_step = buildstep.BuildStep(name="worker_preparation")
         self.preparation_step.setBuild(self)
         yield self.preparation_step.addStep()
-        self.setupOwnProperties()
+        Build.setupBuildProperties(self.getProperties(), self.requests,
+                                   self.sources, self.number)
 
         # then narrow WorkerLocks down to the right worker
-        self.locks = [(l.getLockForWorker(workerforbuilder.worker.workername),
+        self.locks = [(l.getLockForWorker(self.workername),
                        a)
                       for l, a in self.locks]
         metrics.MetricCountEvent.log('active_builds', 1)
@@ -332,7 +340,6 @@ class Build(properties.PropertiesMixin):
         # make sure properties are available to people listening on 'new'
         # events
         yield self.master.data.updates.setBuildProperties(self.buildid, self)
-        self.build_status.buildStarted(self)
         yield self.master.data.updates.setBuildStateString(self.buildid, 'starting')
         yield self.master.data.updates.generateNewBuildEvent(self.buildid)
 
@@ -380,7 +387,7 @@ class Build(properties.PropertiesMixin):
         # us in a build.
         yield self.master.data.updates.setBuildStateString(self.buildid,
                                                            'pinging worker')
-        log.msg("starting build {}.. pinging the worker {}".format(self, workerforbuilder))
+        log.msg(f"starting build {self}.. pinging the worker {workerforbuilder}")
         try:
             ping_success_or_failure = yield workerforbuilder.ping()
         except Exception:
@@ -413,7 +420,7 @@ class Build(properties.PropertiesMixin):
                                                            'acquiring locks')
         yield self.acquireLocks()
 
-        readymsg = "worker {} ready".format(self.getWorkerName())
+        readymsg = f"worker {self.getWorkerName()} ready"
         yield self.master.data.updates.setStepStateString(self.preparation_step.stepid, readymsg)
         yield self.master.data.updates.finishStep(self.preparation_step.stepid, SUCCESS, False)
 
@@ -456,10 +463,10 @@ class Build(properties.PropertiesMixin):
             return defer.succeed(None)
         if self.stopped:
             return defer.succeed(None)
-        log.msg("acquireLocks(build {}, locks {})".format(self, self.locks))
+        log.msg(f"acquireLocks(build {self}, locks {self.locks})")
         for lock, access in self.locks:
             if not lock.isAvailable(self, access):
-                log.msg("Build {} waiting for lock {}".format(self, lock))
+                log.msg(f"Build {self} waiting for lock {lock}")
                 d = lock.waitUntilMaybeAvailable(self, access)
                 d.addCallback(self.acquireLocks)
                 self._acquiringLock = (lock, access, d)
@@ -477,7 +484,7 @@ class Build(properties.PropertiesMixin):
             count = self.stepnames[name]
             count += 1
             self.stepnames[name] = count
-            name = "{}_{}".format(step.name, count)
+            name = f"{step.name}_{count}"
         else:
             self.stepnames[name] = 0
         step.name = name
@@ -565,7 +572,7 @@ class Build(properties.PropertiesMixin):
             yield self.startNextStep()
 
         except Exception as e:
-            log.msg("{} build got exception when running step {}".format(self, step))
+            log.msg(f"{self} build got exception when running step {step}")
             log.err(e)
 
             yield self.master.data.updates.setBuildProperties(self.buildid, self)
@@ -583,11 +590,11 @@ class Build(properties.PropertiesMixin):
         text = None
         if isinstance(results, tuple):
             results, text = results
-        assert isinstance(results, type(SUCCESS)), "got %r" % (results,)
+        assert isinstance(results, type(SUCCESS)), f"got {repr(results)}"
         summary = yield step.getBuildResultSummary()
         if 'build' in summary:
             text = [summary['build']]
-        log.msg(" step '{}' complete: {} ({})".format(step.name, statusToString(results), text))
+        log.msg(f" step '{step.name}' complete: {statusToString(results)} ({text})")
         if text:
             self.text.extend(text)
             self.master.data.updates.setBuildStateString(self.buildid,
@@ -604,7 +611,7 @@ class Build(properties.PropertiesMixin):
         # the worker went away. There are several possible reasons for this,
         # and they aren't necessarily fatal. For now, kill the build, but
         # TODO: see if we can resume the build when it reconnects.
-        log.msg("{}.lostRemote".format(self))
+        log.msg(f"{self}.lostRemote")
         self.conn = None
         self.text = ["lost", "connection"]
         self.results = RETRY
@@ -622,6 +629,7 @@ class Build(properties.PropertiesMixin):
     def controlStopBuild(self, key, params):
         return self.stopBuild(**params)
 
+    @defer.inlineCallbacks
     def stopBuild(self, reason="<no reason given>", results=CANCELLED):
         # the idea here is to let the user cancel a build because, e.g.,
         # they realized they committed a bug and they don't want to waste
@@ -630,13 +638,13 @@ class Build(properties.PropertiesMixin):
         # build as failed quickly rather than waiting for the worker's
         # timeout to kill it on its own.
 
-        log.msg(" {}: stopping build: {} {}".format(self, reason, results))
+        log.msg(f" {self}: stopping build: {reason} {results}")
         if self.finished:
             return
-        # TODO: include 'reason' in this point event
+        self.stopped_reason = reason
         self.stopped = True
         if self.currentStep and self.currentStep.results is None:
-            self.currentStep.interrupt(reason)
+            yield self.currentStep.interrupt(reason)
 
         self.results = results
 
@@ -661,6 +669,8 @@ class Build(properties.PropertiesMixin):
             text = ["cancelled"]
         else:
             text = ["build", "successful"]
+        if self.stopped_reason is not None:
+            text.extend([f'({self.stopped_reason})'])
         text.extend(self.text)
         return self.buildFinished(text, self.results)
 
@@ -685,11 +695,8 @@ class Build(properties.PropertiesMixin):
                 self.subs.unsubscribe()
                 self.subs = None
                 self.conn = None
-            log.msg(" {}: build finished".format(self))
+            log.msg(f" {self}: build finished")
             self.results = worst_status(self.results, results)
-            self.build_status.setText(text)
-            self.build_status.setResults(self.results)
-            self.build_status.buildFinished()
             eventually(self.releaseLocks)
             metrics.MetricCountEvent.log('active_builds', -1)
 
@@ -719,7 +726,7 @@ class Build(properties.PropertiesMixin):
 
     def releaseLocks(self):
         if self.locks:
-            log.msg("releaseLocks({}): {}".format(self, self.locks))
+            log.msg(f"releaseLocks({self}): {self.locks}")
 
         for lock, access in self.locks:
             if lock.isOwner(self, access):
@@ -767,17 +774,18 @@ class Build(properties.PropertiesMixin):
         builder_id = yield self.getBuilderId()
         return getURLForBuild(self.master, builder_id, self.number)
 
+    @defer.inlineCallbacks
+    def get_buildid(self):
+        if self.buildid is not None:
+            return self.buildid
+        buildid = yield self._buildid_notifier.wait()
+        return buildid
+
+    @defer.inlineCallbacks
     def waitUntilFinished(self):
-        return self.master.mq.waitUntilEvent(
-            ('builds', str(self.buildid), 'finished'),
-            lambda: self.finished)
+        buildid = yield self.get_buildid()
+        yield self.master.mq.waitUntilEvent(('builds', str(buildid), 'finished'),
+                                            lambda: self.finished)
 
     def getWorkerInfo(self):
-        return self.workerforbuilder.worker.worker_status.info
-
-    # IBuildControl
-
-    def getStatus(self):
-        return self.build_status
-
-    # stopBuild is defined earlier
+        return self.worker_info
