@@ -19,7 +19,6 @@ import weakref
 from twisted.application import service
 from twisted.internet import defer
 from twisted.python import log
-from zope.interface import implementer
 
 from buildbot import interfaces
 from buildbot.data import resultspec
@@ -76,28 +75,20 @@ class Builder(util_service.ReconfigurableServiceMixin,
         self.workers = []
 
         self.config = None
-        self.builder_status = None
 
         # Tracks config version for locks
         self.config_version = None
 
-    @defer.inlineCallbacks
-    def reconfigServiceWithBuildbotConfig(self, new_config):
-        # find this builder in the config
+    def _find_builder_config_by_name(self, new_config):
         for builder_config in new_config.builders:
             if builder_config.name == self.name:
-                found_config = True
-                break
-        assert found_config, "no config found for builder '{}'".format(self.name)
-
-        # set up a builder status object on the first reconfig
-        if not self.builder_status:
-            self.builder_status = self.master.status.builderAdded(
-                name=builder_config.name,
-                basedir=builder_config.builddir,
-                tags=builder_config.tags,
-                description=builder_config.description)
+                return builder_config
+        raise AssertionError(f"no config found for builder '{self.name}'")
 
+    @defer.inlineCallbacks
+    def reconfigServiceWithBuildbotConfig(self, new_config):
+        builder_config = self._find_builder_config_by_name(new_config)
+        old_config = self.config
         self.config = builder_config
         self.config_version = self.master.config_version
 
@@ -106,14 +97,10 @@ class Builder(util_service.ReconfigurableServiceMixin,
         # build.
         builderid = yield self.getBuilderId()
 
-        self.master.data.updates.updateBuilderInfo(builderid,
-                                                   builder_config.description,
-                                                   builder_config.tags)
-
-        self.builder_status.setDescription(builder_config.description)
-        self.builder_status.setTags(builder_config.tags)
-        self.builder_status.setWorkernames(self.config.workernames)
-        self.builder_status.setCacheSize(new_config.caches['Builds'])
+        if self._has_updated_config_info(old_config, builder_config):
+            yield self.master.data.updates.updateBuilderInfo(builderid,
+                                                             builder_config.description,
+                                                             builder_config.tags)
 
         # if we have any workers attached which are no longer configured,
         # drop them.
@@ -121,8 +108,17 @@ class Builder(util_service.ReconfigurableServiceMixin,
         self.workers = [w for w in self.workers
                         if w.worker.workername in new_workernames]
 
+    def _has_updated_config_info(self, old_config, new_config):
+        if old_config is None:
+            return True
+        if old_config.description != new_config.description:
+            return True
+        if old_config.tags != new_config.tags:
+            return True
+        return False
+
     def __repr__(self):
-        return "<Builder '%r' at %d>" % (self.name, id(self))
+        return f"<Builder '{repr(self.name)}' at {id(self)}>"
 
     def getBuilderIdForName(self, name):
         # buildbot.config should ensure this is already unicode, but it doesn't
@@ -170,7 +166,7 @@ class Builder(util_service.ReconfigurableServiceMixin,
         bldrid = yield self.getBuilderId()
         completed = yield self.master.data.get(
             ('builders', bldrid, 'buildrequests'),
-            [resultspec.Filter('complete', 'eq', [False])],
+            [resultspec.Filter('complete', 'eq', [True])],
             order=['-complete_at'], limit=1)
         if completed:
             return completed[0]['complete_at']
@@ -179,10 +175,10 @@ class Builder(util_service.ReconfigurableServiceMixin,
 
     def getBuild(self, number):
         for b in self.building:
-            if b.build_status and b.build_status.number == number:
+            if b.number == number:
                 return b
         for b in self.old_building:
-            if b.build_status and b.build_status.number == number:
+            if b.number == number:
                 return b
         return None
 
@@ -230,7 +226,7 @@ class Builder(util_service.ReconfigurableServiceMixin,
         self.attaching_workers.append(wfb)
 
         try:
-            wfb = yield wfb.attached(worker, commands)
+            yield wfb.attached(worker, commands)
             self.attaching_workers.remove(wfb)
             self.workers.append(wfb)
             return self
@@ -242,16 +238,19 @@ class Builder(util_service.ReconfigurableServiceMixin,
             log.err(e, 'worker failed to attach')
             return None
 
-    def detached(self, worker):
-        """This is called when the connection to the bot is lost."""
+    def _find_wfb_by_worker(self, worker):
         for wfb in self.attaching_workers + self.workers:
             if wfb.worker == worker:
-                break
-        else:
-            log.msg(("WEIRD: Builder.detached({}) ({})"
-                     " not in attaching_workers({})"
-                     " or workers({})").format(worker, worker.workername, self.attaching_workers,
-                                               self.workers))
+                return wfb
+        return None
+
+    def detached(self, worker):
+        """This is called when the connection to the bot is lost."""
+        wfb = self._find_wfb_by_worker(worker)
+        if wfb is None:
+            log.msg(f"WEIRD: Builder.detached({worker}) ({worker.workername})"
+                    f" not in attaching_workers({self.attaching_workers})"
+                    f" or workers({self.workers})")
             return
 
         if wfb in self.attaching_workers:
@@ -324,7 +323,7 @@ class Builder(util_service.ReconfigurableServiceMixin,
         Build.setupPropertiesKnownBeforeBuildStarts(
             props, build.requests, build.builder, workerforbuilder)
 
-        log.msg("starting build {} using worker {}".format(build, workerforbuilder))
+        log.msg(f"starting build {build} using worker {workerforbuilder}")
 
         # set up locks
         locks = yield build.render(self.config.locks)
@@ -344,22 +343,11 @@ class Builder(util_service.ReconfigurableServiceMixin,
         # another build request.
         workerforbuilder.buildStarted()
 
-        # create the BuildStatus object that goes with the Build
-        bs = self.builder_status.newBuild()
-
-        # let status know
-        self.master.status.build_started(buildrequests[0].id, self.name, bs)
-
-        # start the build. This will first set up the steps, then tell the
-        # BuildStatus that it has started, which will announce it to the world
-        # (through our BuilderStatus object, which is its parent).  Finally it
-        # will start the actual build process.  This is done with a fresh
-        # Deferred since _startBuildFor should not wait until the build is
-        # finished.  This uses `maybeDeferred` to ensure that any exceptions
+        # We put the result of startBuild into a fresh Deferred since _startBuildFor should not
+        # wait until the build is finished.  This uses `maybeDeferred` to ensure that any exceptions
         # raised by startBuild are treated as deferred errbacks (see
         # http://trac.buildbot.net/ticket/2428).
-        d = defer.maybeDeferred(build.startBuild,
-                                bs, workerforbuilder)
+        d = defer.maybeDeferred(build.startBuild, workerforbuilder)
         # this shouldn't happen. if it does, the worker will be wedged
         d.addErrback(log.err, 'from a running build; this is a '
                      'serious error - please file a bug at http://buildbot.net')
@@ -389,7 +377,7 @@ class Builder(util_service.ReconfigurableServiceMixin,
         # which will trigger a check for any now-possible build requests
         # (maybeStartBuilds)
 
-        results = build.build_status.getResults()
+        results = build.results
 
         self.building.remove(build)
         if results == RETRY:
@@ -462,49 +450,3 @@ class Builder(util_service.ReconfigurableServiceMixin,
     @staticmethod
     def _defaultCollapseRequestFn(master, builder, brdict1, brdict2):
         return buildrequest.BuildRequest.canBeCollapsed(master, brdict1, brdict2)
-
-
-@implementer(interfaces.IBuilderControl)
-class BuilderControl:
-
-    def __init__(self, builder, control):
-        self.original = builder
-        self.control = control
-
-    @defer.inlineCallbacks
-    def getPendingBuildRequestControls(self):
-        master = self.original.master
-        # TODO Use DATA API
-        brdicts = yield master.db.buildrequests.getBuildRequests(
-            buildername=self.original.name,
-            claimed=False)
-
-        # convert those into BuildRequest objects
-        buildrequests = []
-        for brdict in brdicts:
-            br = yield buildrequest.BuildRequest.fromBrdict(
-                self.control.master, brdict)
-            buildrequests.append(br)
-
-        # and return the corresponding control objects
-        return [buildrequest.BuildRequestControl(self.original, r)
-            for r in buildrequests]
-
-    def getBuild(self, number):
-        return self.original.getBuild(number)
-
-    def ping(self):
-        if not self.original.workers:
-            return defer.succeed(False)  # interfaces.NoWorkerError
-        dl = []
-        for w in self.original.workers:
-            dl.append(w.ping(self.original.builder_status))
-        d = defer.DeferredList(dl)
-        d.addCallback(self._gatherPingResults)
-        return d
-
-    def _gatherPingResults(self, res):
-        for ignored, success in res:
-            if not success:
-                return False
-        return True
