@@ -15,11 +15,10 @@
 
 
 import copy
+import math
 import random
 from datetime import datetime
 
-from dateutil.tz import tzutc
-
 from twisted.internet import defer
 from twisted.python import log
 from twisted.python.failure import Failure
@@ -30,6 +29,7 @@ from buildbot.process.buildrequest import BuildRequest
 from buildbot.util import deferwaiter
 from buildbot.util import epoch2datetime
 from buildbot.util import service
+from buildbot.util.async_sort import async_sort
 
 
 class BuildChooserBase:
@@ -227,7 +227,7 @@ class BasicBuildChooser(BuildChooserBase):
                     nextBreq = None
             except Exception:
                 log.err(Failure(),
-                        "from _getNextUnclaimedBuildRequest for builder '{}'".format(self.bldr))
+                        f"from _getNextUnclaimedBuildRequest for builder '{self.bldr}'")
                 nextBreq = None
         else:
             # otherwise just return the first build
@@ -248,7 +248,7 @@ class BasicBuildChooser(BuildChooserBase):
                 worker = yield self.nextWorker(self.bldr, self.workerpool, buildrequest)
             except Exception:
                 log.err(Failure(),
-                        "from nextWorker for builder '{}'".format(self.bldr))
+                        f"from nextWorker for builder '{self.bldr}'")
                 worker = None
 
             if not worker or worker not in self.workerpool:
@@ -329,7 +329,7 @@ class BuildRequestDistributor(service.AsyncMultiService):
         try:
             yield self._deferwaiter.add(self._maybeStartBuildsOn(new_builders))
         except Exception as e:  # pragma: no cover
-            log.err(e, "while starting builds on {0}".format(new_builders))
+            log.err(e, f"while starting builds on {new_builders}")
 
     @defer.inlineCallbacks
     def _maybeStartBuildsOn(self, new_builders):
@@ -358,8 +358,7 @@ class BuildRequestDistributor(service.AsyncMultiService):
                 if not self.active:
                     self._activity_loop_deferred = self._activityLoop()
             except Exception:  # pragma: no cover
-                log.err(Failure(),
-                        "while attempting to start builds on {}".format(self.name))
+                log.err(Failure(), f"while attempting to start builds on {self.name}")
 
         yield self.pending_builders_lock.run(
             resetPendingBuildersList, new_builders)
@@ -369,44 +368,23 @@ class BuildRequestDistributor(service.AsyncMultiService):
     def _defaultSorter(self, master, builders):
         timer = metrics.Timer("BuildRequestDistributor._defaultSorter()")
         timer.start()
-        # perform an asynchronous schwarzian transform, transforming None
-        # into sys.maxint so that it sorts to the end
 
-        def xform(bldr):
-            d = defer.maybeDeferred(bldr.getOldestRequestTime)
-            d.addCallback(lambda time:
-                          (((time is None) and None or time), bldr))
-            return d
-        xformed = yield defer.gatherResults(
-            [xform(bldr) for bldr in builders])
+        @defer.inlineCallbacks
+        def key(bldr):
+            # Sort by time of oldest build request
+            time = yield bldr.getOldestRequestTime()
+            if time is None:
+                # for builders that do not have pending buildrequest, we just use large number
+                time = math.inf
+            else:
+                if isinstance(time, datetime):
+                    time = time.timestamp()
+            return (time, bldr.name)
 
-        # sort the transformed list synchronously, comparing None to the end of
-        # the list
-        def xformedKey(a):
-            """
-            Key function can be used to sort a list
-            where each list element is a tuple:
-                (datetime.datetime, Builder)
+        yield async_sort(builders, key)
 
-            @return: a tuple of (date, builder name)
-            """
-            (date, builder) = a
-            if date is None:
-                # Choose a really big date, so that any
-                # date set to 'None' will appear at the
-                # end of the list during comparisons.
-                date = datetime.max
-                # Need to set the timezone on the date, in order
-                # to perform comparisons with other dates which
-                # have the time zone set.
-                date = date.replace(tzinfo=tzutc())
-            return (date, builder.name)
-        xformed.sort(key=xformedKey)
-
-        # and reverse the transform
-        rv = [xf[1] for xf in xformed]
         timer.stop()
-        return rv
+        return builders
 
     @defer.inlineCallbacks
     def _sortBuilders(self, buildernames):
@@ -472,7 +450,7 @@ class BuildRequestDistributor(service.AsyncMultiService):
                 if bldr:
                     yield self._maybeStartBuildsOnBuilder(bldr)
             except Exception:
-                log.err(Failure(), "from maybeStartBuild for builder '{}'".format(bldr_name))
+                log.err(Failure(), f"from maybeStartBuild for builder '{bldr_name}'")
 
             self.activity_lock.release()
 
