@@ -25,6 +25,7 @@ from buildbot.process import metrics
 from buildbot.process.results import CANCELLED
 from buildbot.process.results import FAILURE
 from buildbot.process.results import SUCCESS
+from buildbot.util import lineboundaries
 from buildbot.util.eventual import eventually
 from buildbot.worker.protocols import base
 
@@ -63,6 +64,7 @@ class RemoteCommand(base.RemoteCommandImpl):
         self.ignore_updates = ignore_updates
         self.decodeRC = decodeRC
         self.conn = None
+        self._is_conn_test_fake = False
         self.worker = None
         self.step = None
         self.builder_name = None
@@ -73,9 +75,21 @@ class RemoteCommand(base.RemoteCommandImpl):
         # This is really only a problem with old-style steps, which do not
         # wait for the Deferred from one method before invoking the next.
         self.loglock = defer.DeferredLock()
+        self._line_boundary_finders = {}
 
     def __repr__(self):
-        return "<RemoteCommand '{}' at {}>".format(self.remote_command, id(self))
+        return f"<RemoteCommand '{self.remote_command}' at {id(self)}>"
+
+    @classmethod
+    def generate_new_command_id(cls):
+        cmd_id = cls._commandCounter
+        cls._commandCounter += 1
+        return f"{cmd_id}"
+
+    @classmethod
+    def get_last_generated_command_id(cls):
+        cmd_id = cls._commandCounter - 1
+        return f"{cmd_id}"
 
     def run(self, step, conn, builder_name):
         self.active = True
@@ -83,12 +97,12 @@ class RemoteCommand(base.RemoteCommandImpl):
         self.conn = conn
         self.builder_name = builder_name
 
-        # generate a new command id
-        cmd_id = RemoteCommand._commandCounter
-        RemoteCommand._commandCounter += 1
-        self.commandID = "%d" % cmd_id
+        # This probably could be solved in a cleaner way.
+        self._is_conn_test_fake = hasattr(self.conn, 'is_fake_test_connection')
 
-        log.msg("{}: RemoteCommand.run [{}]".format(self, self.commandID))
+        self.commandID = RemoteCommand.generate_new_command_id()
+
+        log.msg(f"{self}: RemoteCommand.run [{self.commandID}]")
         self.deferred = defer.Deferred()
 
         d = defer.maybeDeferred(self._start)
@@ -133,14 +147,20 @@ class RemoteCommand(base.RemoteCommandImpl):
 
     @defer.inlineCallbacks
     def _finished(self, failure=None):
+        # Finished may be called concurrently by a message from worker and interruption due to
+        # lost connection.
+        if not self.active:
+            return
         self.active = False
+
         # the rc is send asynchronously and there is a chance it is still in the callback queue
         # when finished is received, we have to workaround in the master because worker might be
         # older
-        timeout = 10
-        while self.rc is None and timeout > 0:
-            yield util.asyncSleep(.1)
-            timeout -= 1
+        if not self._is_conn_test_fake:
+            timeout = 10
+            while self.rc is None and timeout > 0:
+                yield util.asyncSleep(.1)
+                timeout -= 1
 
         try:
             yield self.remoteComplete(failure)
@@ -152,17 +172,20 @@ class RemoteCommand(base.RemoteCommandImpl):
     @defer.inlineCallbacks
     def interrupt(self, why):
         log.msg("RemoteCommand.interrupt", self, why)
+
+        if self.conn and isinstance(why, Failure) and why.check(error.ConnectionLost):
+            # Note that we may be in the process of interruption and waiting for the worker to
+            # return the final results when the connection is disconnected.
+            log.msg("RemoteCommand.interrupt: lost worker")
+            self.conn = None
+            self._finished(why)
+            return
         if not self.active or self.interrupted:
             log.msg(" but this RemoteCommand is already inactive")
             return
         if not self.conn:
             log.msg(" but our .conn went away")
             return
-        if isinstance(why, Failure) and why.check(error.ConnectionLost):
-            log.msg("RemoteCommand.disconnect: lost worker")
-            self.conn = None
-            self._finished(why)
-            return
 
         self.interrupted = True
         # tell the remote command to halt. Returns a Deferred that will fire
@@ -175,6 +198,29 @@ class RemoteCommand(base.RemoteCommandImpl):
         except Exception as e:
             log.msg("RemoteCommand.interrupt failed", self, e)
 
+    def remote_update_msgpack(self, updates):
+        self.worker.messageReceivedFromWorker()
+        try:
+            for key, value in updates:
+                if self.active and not self.ignore_updates:
+                    if key in ['stdout', 'stderr', 'header']:
+                        self.remoteUpdate(key, value[0], False)
+                    elif key == "log":
+                        logname, data = value
+                        self.remoteUpdate(key, (logname, data[0]), False)
+                    else:
+                        self.remoteUpdate(key, value, False)
+        except Exception:
+            # log failure, terminate build, let worker retire the update
+            self._finished(Failure())
+
+    def split_line(self, stream, text):
+        try:
+            return self._line_boundary_finders[stream].append(text)
+        except KeyError:
+            lbf = self._line_boundary_finders[stream] = lineboundaries.LineBoundaryFinder()
+            return lbf.append(text)
+
     def remote_update(self, updates):
         """
         I am called by the worker's
@@ -187,11 +233,24 @@ class RemoteCommand(base.RemoteCommandImpl):
         updates = decode(updates)
         self.worker.messageReceivedFromWorker()
         max_updatenum = 0
-        for (update, num) in updates:
+        for (update, num) in updates:  # noqa pylint: disable=too-many-nested-blocks
             # log.msg("update[%d]:" % num)
             try:
                 if self.active and not self.ignore_updates:
-                    self.remoteUpdate(update)
+                    for key, value in update.items():
+                        if key in ['stdout', 'stderr', 'header']:
+                            whole_line = self.split_line(key, value)
+                            if whole_line is not None:
+                                self.remoteUpdate(key, whole_line, False)
+                        elif key == "log":
+                            logname, data = value
+                            whole_line = self.split_line(logname, data)
+                            value = (logname, whole_line)
+                            if whole_line is not None:
+                                self.remoteUpdate(key, value, False)
+                        else:
+                            self.remoteUpdate(key, value, False)
+
             except Exception:
                 # log failure, terminate build, let worker retire the update
                 self._finished(Failure())
@@ -226,6 +285,16 @@ class RemoteCommand(base.RemoteCommandImpl):
             self.logs[self.stdioLogName].addStdout(data)
         return defer.succeed(None)
 
+    @util.deferredLocked('loglock')
+    def add_stdout_lines(self, data, is_flushed):
+        if self.collectStdout:
+            if is_flushed:
+                data = data[:-1]
+            self.stdout += data
+        if self.stdioLogName is not None and self.stdioLogName in self.logs:
+            self.logs[self.stdioLogName].add_stdout_lines(data)
+        return defer.succeed(None)
+
     @util.deferredLocked('loglock')
     def addStderr(self, data):
         if self.collectStderr:
@@ -234,12 +303,28 @@ class RemoteCommand(base.RemoteCommandImpl):
             self.logs[self.stdioLogName].addStderr(data)
         return defer.succeed(None)
 
+    @util.deferredLocked('loglock')
+    def add_stderr_lines(self, data, is_flushed):
+        if self.collectStderr:
+            if is_flushed:
+                data = data[:-1]
+            self.stderr += data
+        if self.stdioLogName is not None and self.stdioLogName in self.logs:
+            self.logs[self.stdioLogName].add_stderr_lines(data)
+        return defer.succeed(None)
+
     @util.deferredLocked('loglock')
     def addHeader(self, data):
         if self.stdioLogName is not None and self.stdioLogName in self.logs:
             self.logs[self.stdioLogName].addHeader(data)
         return defer.succeed(None)
 
+    @util.deferredLocked('loglock')
+    def add_header_lines(self, data):
+        if self.stdioLogName is not None and self.stdioLogName in self.logs:
+            self.logs[self.stdioLogName].add_header_lines(data)
+        return defer.succeed(None)
+
     @util.deferredLocked('loglock')
     @defer.inlineCallbacks
     def addToLog(self, logname, data):
@@ -252,70 +337,83 @@ class RemoteCommand(base.RemoteCommandImpl):
             self._closeWhenFinished[logname] = closeWhenFinished
 
         if logname in self.logs:
-            yield self.logs[logname].addStdout(data)
+            yield self.logs[logname].add_stdout_lines(data)
         else:
-            log.msg("{}.addToLog: no such log {}".format(self, logname))
+            log.msg(f"{self}.addToLog: no such log {logname}")
 
     @metrics.countMethod('RemoteCommand.remoteUpdate()')
     @defer.inlineCallbacks
-    def remoteUpdate(self, update):
+    def remoteUpdate(self, key, value, is_flushed):
         def cleanup(data):
             if self.step is None:
                 return data
             return self.step.build.properties.cleanupTextFromSecrets(data)
 
         if self.debug:
-            for k, v in update.items():
-                log.msg("Update[{}]: {}".format(k, v))
-        if "stdout" in update:
-            # 'stdout': data
-            yield self.addStdout(cleanup(update['stdout']))
-        if "stderr" in update:
-            # 'stderr': data
-            yield self.addStderr(cleanup(update['stderr']))
-        if "header" in update:
-            # 'header': data
-            yield self.addHeader(cleanup(update['header']))
-        if "log" in update:
-            # 'log': (logname, data)
-            logname, data = update['log']
+            log.msg(f"Update[{key}]: {value}")
+        if key == "stdout":
+            yield self.add_stdout_lines(cleanup(value), is_flushed)
+        if key == "stderr":
+            yield self.add_stderr_lines(cleanup(value), is_flushed)
+        if key == "header":
+            yield self.add_header_lines(cleanup(value))
+        if key == "log":
+            logname, data = value
             yield self.addToLog(logname, cleanup(data))
-        if "rc" in update:
-            rc = self.rc = update['rc']
-            log.msg("{} rc={}".format(self, rc))
-            yield self.addHeader("program finished with exit code %d\n" % rc)
-        if "elapsed" in update:
-            self._remoteElapsed = update['elapsed']
+        if key == "rc":
+            rc = self.rc = value
+            log.msg(f"{self} rc={rc}")
+            yield self.add_header_lines(f"program finished with exit code {rc}\n")
+        if key == "elapsed":
+            self._remoteElapsed = value
 
         # TODO: these should be handled at the RemoteCommand level
-        for k in update:
-            if k not in ('stdout', 'stderr', 'header', 'rc'):
-                if k not in self.updates:
-                    self.updates[k] = []
-                self.updates[k].append(update[k])
+        if key not in ('stdout', 'stderr', 'header', 'rc'):
+            if key not in self.updates:
+                self.updates[key] = []
+            self.updates[key].append(value)
 
-    @util.deferredLocked('loglock')
     @defer.inlineCallbacks
     def remoteComplete(self, maybeFailure):
         if self._startTime and self._remoteElapsed:
             delta = (util.now() - self._startTime) - self._remoteElapsed
             metrics.MetricTimeEvent.log("RemoteCommand.overhead", delta)
 
-        for name, loog in self.logs.items():
-            if self._closeWhenFinished[name]:
-                if maybeFailure:
-                    loog = yield self._unwrap(loog)
-                    yield loog.addHeader("\nremoteFailed: {}".format(maybeFailure))
-                else:
-                    log.msg("closing log {}".format(loog))
-                loog.finish()
+        for key, lbf in self._line_boundary_finders.items():
+            if key in ['stdout', 'stderr', 'header']:
+                whole_line = lbf.flush()
+                if whole_line is not None:
+                    yield self.remoteUpdate(key, whole_line, True)
+            else:
+                logname = key
+                whole_line = lbf.flush()
+                value = (logname, whole_line)
+                if whole_line is not None:
+                    yield self.remoteUpdate("log", value, True)
+
+        try:
+            yield self.loglock.acquire()
+            for name, loog in self.logs.items():
+                if self._closeWhenFinished[name]:
+                    if maybeFailure:
+                        yield loog.addHeader(f"\nremoteFailed: {maybeFailure}")
+                    else:
+                        log.msg(f"closing log {loog}")
+                    yield loog.finish()
+        finally:
+            yield self.loglock.release()
+
         if maybeFailure:
+            # Message Pack protocol can not send an exception object back to the master, so
+            # exception information is sent as a string
+            if isinstance(maybeFailure, str):
+                raise RemoteException(maybeFailure)
+
             # workaround http://twistedmatrix.com/trac/ticket/5507
             # CopiedFailure cannot be raised back, this make debug difficult
             if isinstance(maybeFailure, pb.CopiedFailure):
-                maybeFailure.value = RemoteException("{}: {}\n{}".format(maybeFailure.type,
-                                                                         maybeFailure.value,
-                                                                         maybeFailure.traceback))
+                maybeFailure.value = RemoteException(f"{maybeFailure.type}: {maybeFailure.value}"
+                                                     f"\n{maybeFailure.traceback}")
                 maybeFailure.type = RemoteException
             maybeFailure.raiseException()
 
@@ -402,9 +500,9 @@ class RemoteShellCommand(RemoteCommand):
                 self.args['dir'] = self.args['workdir']
             if self.step.workerVersionIsOlderThan("shell", "2.16"):
                 self.args.pop('sigtermTime', None)
-        what = "command '{}' in dir '{}'".format(self.fake_command, self.args['workdir'])
+        what = f"command '{self.fake_command}' in dir '{self.args['workdir']}'"
         log.msg(what)
         return super()._start()
 
     def __repr__(self):
-        return "<RemoteShellCommand '{}'>".format(repr(self.fake_command))
+        return f"<RemoteShellCommand '{repr(self.fake_command)}'>"
