@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from future.utils import string_types
-
 from twisted.internet import defer
 from twisted.python import log
 
@@ -55,22 +53,22 @@ class CommandlineUserManagerPerspective(pbutil.NewCredPerspective):
             # list, alternating ident, uid
             formatted_results += "user(s) added:\n"
             for user in results:
-                if isinstance(user, string_types):
-                    formatted_results += "identifier: %s\n" % user
+                if isinstance(user, str):
+                    formatted_results += f"identifier: {user}\n"
                 else:
-                    formatted_results += "uid: %d\n\n" % user
+                    formatted_results += f"uid: {user}\n\n"
         elif op == 'remove':
             # list of dictionaries
             formatted_results += "user(s) removed:\n"
             for user in results:
                 if user:
-                    formatted_results += "identifier: %s\n" % (user)
+                    formatted_results += f"identifier: {user}\n"
         elif op == 'update':
             # list, alternating ident, None
             formatted_results += "user(s) updated:\n"
             for user in results:
                 if user:
-                    formatted_results += "identifier: %s\n" % (user)
+                    formatted_results += f"identifier: {user}\n"
         elif op == 'get':
             # list of dictionaries
             formatted_results += "user(s) found:\n"
@@ -78,7 +76,7 @@ class CommandlineUserManagerPerspective(pbutil.NewCredPerspective):
                 if user:
                     for key in sorted(user.keys()):
                         if key != 'bb_password':
-                            formatted_results += "%s: %s\n" % (key, user[key])
+                            formatted_results += f"{key}: {user[key]}\n"
                     formatted_results += "\n"
                 else:
                     formatted_results += "no match found\n"
@@ -127,12 +125,12 @@ class CommandlineUserManagerPerspective(pbutil.NewCredPerspective):
                         yield self.master.db.users.removeUser(uid)
                         result = user
                     else:
-                        log.msg("Unable to find uid for identifier %s" % user)
+                        log.msg(f"Unable to find uid for identifier {user}")
                 elif op == 'get':
                     if uid:
                         result = yield self.master.db.users.getUser(uid)
                     else:
-                        log.msg("Unable to find uid for identifier %s" % user)
+                        log.msg(f"Unable to find uid for identifier {user}")
 
                 results.append(result)
         else:
@@ -154,8 +152,7 @@ class CommandlineUserManagerPerspective(pbutil.NewCredPerspective):
                             bb_password=bb_password)
                         results.append(ident)
                     else:
-                        log.msg("Unable to find uid for identifier %s"
-                                % user)
+                        log.msg(f"Unable to find uid for identifier {user}")
                 else:
                     # when adding, we update the user after the first attr
                     once_through = False
@@ -171,8 +168,7 @@ class CommandlineUserManagerPerspective(pbutil.NewCredPerspective):
                                     attr_type=attr,
                                     attr_data=user[attr])
                             else:
-                                log.msg("Unable to find uid for identifier %s"
-                                        % user)
+                                log.msg(f"Unable to find uid for identifier {user}")
                         elif op == 'add':
                             result = yield self.master.db.users.findUserByAttr(
                                 identifier=ident,
@@ -197,7 +193,7 @@ class CommandlineUserManager(service.AsyncMultiService):
     """
 
     def __init__(self, username=None, passwd=None, port=None):
-        service.AsyncMultiService.__init__(self)
+        super().__init__()
         assert username and passwd, ("A username and password pair must be given "
                                      "to connect and use `buildbot user`")
         self.username = username
@@ -207,15 +203,15 @@ class CommandlineUserManager(service.AsyncMultiService):
         self.port = port
         self.registration = None
 
+    @defer.inlineCallbacks
     def startService(self):
         # set up factory and register with buildbot.pbmanager
         def factory(mind, username):
             return CommandlineUserManagerPerspective(self.master)
-        self.registration = self.master.pbmanager.register(self.port,
-                                                           self.username,
-                                                           self.passwd,
-                                                           factory)
-        return service.AsyncMultiService.startService(self)
+
+        self.registration = yield self.master.pbmanager.register(self.port, self.username,
+                                                                 self.passwd, factory)
+        yield super().startService()
 
     def stopService(self):
         d = defer.maybeDeferred(service.AsyncMultiService.stopService, self)
@@ -224,4 +220,5 @@ class CommandlineUserManager(service.AsyncMultiService):
         def unreg(_):
             if self.registration:
                 return self.registration.unregister()
+            return None
         return d
