@@ -74,14 +74,7 @@ class AbstractWorkerForBuilder:
 
     def buildStarted(self):
         self.state = States.BUILDING
-        # AbstractWorker doesn't always have a buildStarted method
-        # so only call it if it is available.
-        try:
-            worker_buildStarted = self.worker.buildStarted
-        except AttributeError:
-            pass
-        else:
-            worker_buildStarted(self)
+        self.worker.buildStarted(self)
 
     def buildFinished(self):
         self.state = States.AVAILABLE
@@ -102,10 +95,9 @@ class AbstractWorkerForBuilder:
             self.worker.addWorkerForBuilder(self)
         else:
             assert self.worker == worker
-        log.msg("Worker {} attached to {}".format(worker.workername, self.builder_name))
+        log.msg(f"Worker {worker.workername} attached to {self.builder_name}")
 
         yield self.worker.conn.remotePrint(message="attached")
-        return self
 
     def substantiate_if_needed(self, build):
         return defer.succeed(True)
@@ -113,12 +105,9 @@ class AbstractWorkerForBuilder:
     def insubstantiate_if_needed(self):
         pass
 
-    def ping(self, status=None):
+    def ping(self):
         """Ping the worker to make sure it is still there. Returns a Deferred
         that fires with True if it is.
-
-        @param status: if you point this at a BuilderStatus, a 'pinging'
-                       event will be pushed.
         """
         newping = not self.ping_watchers
         d = defer.Deferred()
@@ -139,7 +128,7 @@ class AbstractWorkerForBuilder:
             d.callback(res)
 
     def detached(self):
-        log.msg("Worker {} detached from {}".format(self.worker.workername, self.builder_name))
+        log.msg(f"Worker {self.worker.workername} detached from {self.builder_name}")
         if self.worker:
             self.worker.removeWorkerForBuilder(self)
         self.worker = None
@@ -189,14 +178,12 @@ class WorkerForBuilder(AbstractWorkerForBuilder):
 
     @defer.inlineCallbacks
     def attached(self, worker, commands):
-        wfb = yield super().attached(worker, commands)
+        yield super().attached(worker, commands)
 
         # Only set available on non-latent workers, since latent workers
         # only attach while a build is in progress.
         self.state = States.AVAILABLE
 
-        return wfb
-
     def detached(self):
         super().detached()
         if self.worker:
@@ -213,7 +200,7 @@ class LatentWorkerForBuilder(AbstractWorkerForBuilder):
         self.state = States.AVAILABLE
         self.setBuilder(builder)
         self.worker.addWorkerForBuilder(self)
-        log.msg("Latent worker {} attached to {}".format(worker.workername, self.builder_name))
+        log.msg(f"Latent worker {worker.workername} attached to {self.builder_name}")
 
     def substantiate_if_needed(self, build):
         self.state = States.DETACHED
@@ -233,7 +220,7 @@ class LatentWorkerForBuilder(AbstractWorkerForBuilder):
     def substantiate(self, build):
         return self.worker.substantiate(self, build)
 
-    def ping(self, status=None):
+    def ping(self):
         if not self.worker.substantiated:
             return defer.fail(PingException("worker is not substantiated"))
-        return super().ping(status)
+        return super().ping()
