@@ -28,14 +28,14 @@ from buildbot.util import in_reactor
 @in_reactor
 @defer.inlineCallbacks
 def dataspec(config):
-    master = yield fakemaster.make_master()
+    master = yield fakemaster.make_master(None, wantRealReactor=True)
     data = connector.DataConnector()
-    data.setServiceParent(master)
+    yield data.setServiceParent(master)
     if config['out'] != '--':
         dirs = os.path.dirname(config['out'])
         if dirs and not os.path.exists(dirs):
             os.makedirs(dirs)
-        f = open(config['out'], "w")
+        f = open(config['out'], "w", encoding='utf-8')  # noqa pylint: disable=consider-using-with
     else:
         f = sys.stdout
     if config['global'] is not None:
