@@ -135,7 +135,7 @@ class BBService(win32serviceutil.ServiceFramework):
             if os.path.isfile(msg_file):
                 servicemanager.Initialize("BuildBot", msg_file)
             else:
-                self.warning("Strange - '{}' does not exist".format(msg_file))
+                self.warning(f"Strange - '{msg_file}' does not exist")
 
     def _checkConfig(self):
         # Locate our child process runner (but only when run from source)
@@ -156,7 +156,7 @@ class BBService(win32serviceutil.ServiceFramework):
             if me.endswith(".pyc") or me.endswith(".pyo"):
                 me = me[:-1]
 
-            self.runner_prefix = '"{}" "{}"'.format(python_exe, me)
+            self.runner_prefix = f'"{python_exe}" "{me}"'
         else:
             # Running from a py2exe built executable - our child process is
             # us (but with the funky cmdline args!)
@@ -194,7 +194,7 @@ class BBService(win32serviceutil.ServiceFramework):
             if os.path.isfile(sentinal):
                 self.dirs.append(d)
             else:
-                msg = "Directory '{}' is not a buildbot dir - ignoring".format(d)
+                msg = f"Directory '{d}' is not a buildbot dir - ignoring"
                 self.warning(msg)
         if not self.dirs:
             self.error("No valid buildbot directories were specified.\n"
@@ -227,12 +227,11 @@ class BBService(win32serviceutil.ServiceFramework):
         child_infos = []
 
         for bbdir in self.dirs:
-            self.info("Starting BuildBot in directory '{}'".format(bbdir))
+            self.info(f"Starting BuildBot in directory '{bbdir}'")
             # hWaitStop is a Handle but the command needs the int associated
             # to that Handle
             hstop = int(self.hWaitStop)
-            cmd = '{} --spawn {} start --nodaemon {}'.format(self.runner_prefix, hstop, bbdir)
-
+            cmd = f'{self.runner_prefix} --spawn {hstop} start --nodaemon {bbdir}'
             h, t, output = self.createProcess(cmd)
             child_infos.append((bbdir, h, t, output))
 
@@ -257,8 +256,8 @@ class BBService(win32serviceutil.ServiceFramework):
                           "Please check the twistd.log file in the "
                           "indicated directory.")
 
-            self.warning(("BuildBot for directory {} terminated with "
-                          "exit code {}.\n{}").format(repr(bbdir), status, output))
+            self.warning(f"BuildBot for directory {repr(bbdir)} terminated with "
+                         f"exit code {status}.\n{output}")
 
             del child_infos[index]
 
@@ -272,7 +271,7 @@ class BBService(win32serviceutil.ServiceFramework):
         # The child processes should have also seen our stop signal
         # so wait for them to terminate.
         for bbdir, h, t, output in child_infos:
-            for i in range(10):  # 30 seconds to shutdown...
+            for _ in range(10):  # 30 seconds to shutdown...
                 self.ReportServiceStatus(win32service.SERVICE_STOP_PENDING)
                 rc = win32event.WaitForSingleObject(h, 3000)
                 if rc == win32event.WAIT_OBJECT_0:
@@ -284,8 +283,8 @@ class BBService(win32serviceutil.ServiceFramework):
             self.ReportServiceStatus(win32service.SERVICE_STOP_PENDING)
             # If necessary, kill it
             if win32process.GetExitCodeProcess(h) == win32con.STILL_ACTIVE:
-                self.warning("BuildBot process at %r failed to terminate - "
-                             "killing it" % (bbdir, ))
+                self.warning(f"BuildBot process at {repr(bbdir)} failed to terminate - "
+                             "killing it")
                 win32api.TerminateProcess(h, 3)
             self.ReportServiceStatus(win32service.SERVICE_STOP_PENDING)
 
@@ -293,7 +292,7 @@ class BBService(win32serviceutil.ServiceFramework):
             # process terminated.
             # As we are shutting down, we do the join with a little more care,
             # reporting progress as we wait (even though we never will <wink>)
-            for i in range(5):
+            for _ in range(5):
                 t.join(1)
                 self.ReportServiceStatus(win32service.SERVICE_STOP_PENDING)
                 if not t.is_alive():
@@ -314,7 +313,7 @@ class BBService(win32serviceutil.ServiceFramework):
             servicemanager.LogMsg(servicemanager.EVENTLOG_INFORMATION_TYPE,
                                   event,
                                   (self._svc_name_,
-                                   " ({})".format(self._svc_display_name_)))
+                                   f" ({self._svc_display_name_})"))
         except win32api.error as details:
             # Failed to write a log entry - most likely problem is
             # that the event log is full.  We don't want this to kill us
@@ -400,12 +399,12 @@ class BBService(win32serviceutil.ServiceFramework):
         # self.info("Redirect thread starting")
         while True:
             try:
-                ec, data = win32file.ReadFile(handle, CHILDCAPTURE_BLOCK_SIZE)
+                _, data = win32file.ReadFile(handle, CHILDCAPTURE_BLOCK_SIZE)
             except pywintypes.error as err:
                 # ERROR_BROKEN_PIPE means the child process closed the
                 # handle - ie, it terminated.
                 if err[0] != winerror.ERROR_BROKEN_PIPE:
-                    self.warning("Error reading output from process: {}".format(err))
+                    self.warning(f"Error reading output from process: {err}")
                 break
             captured_blocks.append(data)
             del captured_blocks[CHILDCAPTURE_MAX_BLOCKS:]
@@ -527,7 +526,7 @@ def DetermineRunner(bbdir):
         import buildbot.scripts.runner
         return buildbot.scripts.runner.run
 
-    with open(tacfile, 'r') as f:
+    with open(tacfile, 'r', encoding='utf-8') as f:
         contents = f.read()
 
     try:
