@@ -15,8 +15,6 @@
 """
 secret provider interface
 """
-from __future__ import absolute_import
-from __future__ import print_function
 
 import abc
 
