@@ -81,7 +81,7 @@ class HTTPStep(BuildStep):
                 "Need to install txrequest to use this step:\n\n pip install txrequests")
 
         if method not in ('POST', 'GET', 'PUT', 'DELETE', 'HEAD', 'OPTIONS'):
-            config.error("Wrong method given: '{}' is not known".format(method))
+            config.error(f"Wrong method given: '{method}' is not known")
 
         self.method = method
         self.url = url
@@ -113,30 +113,30 @@ class HTTPStep(BuildStep):
 
         # known methods already tested in __init__
 
-        yield log.addHeader('Performing {} request to {}\n'.format(self.method, self.url))
+        yield log.addHeader(f'Performing {self.method} request to {self.url}\n')
         if self.params:
             yield log.addHeader('Parameters:\n')
             params = sorted(self.params.items(), key=lambda x: x[0])
             requestkwargs['params'] = params
             for k, v in params:
-                yield log.addHeader('\t{}: {}\n'.format(k, v))
+                yield log.addHeader(f'\t{k}: {v}\n')
         data = requestkwargs.get("data", None)
         if data:
             yield log.addHeader('Data:\n')
             if isinstance(data, dict):
                 for k, v in data.items():
-                    yield log.addHeader('\t{}: {}\n'.format(k, v))
+                    yield log.addHeader(f'\t{k}: {v}\n')
             else:
-                yield log.addHeader('\t{}\n'.format(data))
+                yield log.addHeader(f'\t{data}\n')
 
         try:
             r = yield self.session.request(**requestkwargs)
         except requests.exceptions.ConnectionError as e:
-            yield log.addStderr('An exception occurred while performing the request: {}'.format(e))
+            yield log.addStderr(f'An exception occurred while performing the request: {e}')
             return FAILURE
 
         if r.history:
-            yield log.addStdout('\nRedirected %d times:\n\n' % len(r.history))
+            yield log.addStdout(f'\nRedirected {len(r.history)} times:\n\n')
             for rr in r.history:
                 yield self.log_response(log, rr)
                 yield log.addStdout('=' * 60 + '\n')
@@ -145,8 +145,8 @@ class HTTPStep(BuildStep):
 
         yield log.finish()
 
-        self.descriptionDone = ["Status code: %d" % r.status_code]
-        if (r.status_code < 400):
+        self.descriptionDone = [f"Status code: {r.status_code}"]
+        if r.status_code < 400:
             return SUCCESS
         else:
             return FAILURE
@@ -158,22 +158,22 @@ class HTTPStep(BuildStep):
         for k, v in response.request.headers.items():
             if k.casefold() in self.hide_request_headers:
                 v = '<HIDDEN>'
-            yield log.addHeader('\t{}: {}\n'.format(k, v))
+            yield log.addHeader(f'\t{k}: {v}\n')
 
-        yield log.addStdout('URL: {}\n'.format(response.url))
+        yield log.addStdout(f'URL: {response.url}\n')
 
         if response.status_code == requests.codes.ok:
-            yield log.addStdout('Status: {}\n'.format(response.status_code))
+            yield log.addStdout(f'Status: {response.status_code}\n')
         else:
-            yield log.addStderr('Status: {}\n'.format(response.status_code))
+            yield log.addStderr(f'Status: {response.status_code}\n')
 
         yield log.addHeader('Response Headers:\n')
         for k, v in response.headers.items():
             if k.casefold() in self.hide_response_headers:
                 v = '<HIDDEN>'
-            yield log.addHeader('\t{}: {}\n'.format(k, v))
+            yield log.addHeader(f'\t{k}: {v}\n')
 
-        yield log.addStdout(' ------ Content ------\n{}'.format(response.text))
+        yield log.addStdout(f' ------ Content ------\n{response.text}')
         content_log = yield self.addLog('content')
         yield content_log.addStdout(response.text)
 
