@@ -56,12 +56,12 @@ git_describe_flags = [
     # string parameter
     ('match', lambda v: ['--match', v] if v else None),
     # numeric parameter
-    ('abbrev', lambda v: ['--abbrev={}'.format(v)]
+    ('abbrev', lambda v: [f'--abbrev={v}']
      if isTrueOrIsExactlyZero(v) else None),
-    ('candidates', lambda v: ['--candidates={}'.format(v)] if isTrueOrIsExactlyZero(v) else None),
+    ('candidates', lambda v: [f'--candidates={v}'] if isTrueOrIsExactlyZero(v) else None),
     # optional string parameter
     ('dirty', lambda v: ['--dirty'] if (v is True or v == '') else None),
-    ('dirty', lambda v: ['--dirty={}'.format(v)] if (v and v is not True) else None),
+    ('dirty', lambda v: [f'--dirty={v}'] if (v and v is not True) else None),
 ]
 
 
@@ -106,8 +106,8 @@ class Git(Source, GitStepMixin):
 
         if isinstance(self.mode, str):
             if not self._hasAttrGroupMember('mode', self.mode):
-                bbconfig.error("Git: mode must be {}".format(
-                        ' or '.join(self._listAttrGroupMembers('mode'))))
+                bbconfig.error(
+                    f"Git: mode must be {' or '.join(self._listAttrGroupMembers('mode'))}")
             if isinstance(self.method, str):
                 if self.mode == 'full' and \
                         self.method not in ['clean', 'fresh', 'clobber', 'copy', None]:
@@ -267,7 +267,7 @@ class Git(Source, GitStepMixin):
         revision = stdout.strip()
         if len(revision) != GIT_HASH_LENGTH:
             raise buildstep.BuildStepFailed()
-        log.msg("Got Git revision {}".format(revision))
+        log.msg(f"Got Git revision {revision}")
         self.updateSourceProperty('got_revision', revision)
 
         return RC_SUCCESS
@@ -305,7 +305,7 @@ class Git(Source, GitStepMixin):
         return self.workdir
 
     @defer.inlineCallbacks
-    def _fetch(self, _):
+    def _fetch(self, _, abandonOnFailure=True):
         fetch_required = True
 
         # If the revision already exists in the repo, we don't need to fetch.
@@ -327,15 +327,16 @@ class Git(Source, GitStepMixin):
                 else:
                     log.msg("Git versions < 1.7.2 don't support progress")
 
-            yield self._dovccmd(command)
+            res = yield self._dovccmd(command, abandonOnFailure=abandonOnFailure)
+            if res != RC_SUCCESS:
+                return res
 
         if self.revision:
             rev = self.revision
         else:
             rev = 'FETCH_HEAD'
         command = ['checkout', '-f', rev]
-        abandonOnFailure = not self.retryFetch and not self.clobberOnFailure
-        res = yield self._dovccmd(command, abandonOnFailure)
+        res = yield self._dovccmd(command, abandonOnFailure=abandonOnFailure)
 
         # Rename the branch if needed.
         if res == RC_SUCCESS and self.branch != 'HEAD':
@@ -350,7 +351,10 @@ class Git(Source, GitStepMixin):
         Handles fallbacks for failure of fetch,
         wrapper for self._fetch
         """
-        res = yield self._fetch(None)
+
+        abandonOnFailure = not self.retryFetch and not self.clobberOnFailure
+
+        res = yield self._fetch(None, abandonOnFailure=abandonOnFailure)
         if res == RC_SUCCESS:
             return res
         elif self.retryFetch:
@@ -408,8 +412,7 @@ class Git(Source, GitStepMixin):
         if self.retry and not done:
             delay, repeats = self.retry
             if repeats > 0:
-                log.msg("Checkout failed, trying %d more times after %d seconds"
-                        % (repeats, delay))
+                log.msg(f"Checkout failed, trying {repeats} more times after {delay} seconds")
                 self.retry = (delay, repeats - 1)
 
                 df = defer.Deferred()
@@ -697,7 +700,7 @@ class GitCommit(buildstep.BuildStep, GitStepMixin, CompositeStepMixin):
 
     def __init__(self, workdir=None, paths=None, messages=None, env=None,
                  timeout=20 * 60, logEnviron=True, emptyCommits='disallow',
-                 config=None, **kwargs):
+                 config=None, no_verify=False, **kwargs):
 
         self.workdir = workdir
         self.messages = messages
@@ -707,6 +710,7 @@ class GitCommit(buildstep.BuildStep, GitStepMixin, CompositeStepMixin):
         self.logEnviron = logEnviron
         self.config = config
         self.emptyCommits = emptyCommits
+        self.no_verify = no_verify
         # The repourl, sshPrivateKey and sshHostKey attributes are required by
         # GitStepMixin, but aren't needed by git add and commit operations
         self.repourl = " "
@@ -782,6 +786,9 @@ class GitCommit(buildstep.BuildStep, GitStepMixin, CompositeStepMixin):
         if self.emptyCommits == 'create-empty-commit':
             cmd.extend(['--allow-empty'])
 
+        if self.no_verify:
+            cmd.extend(['--no-verify'])
+
         ret = yield self._dovccmd(cmd)
         return ret
 
