@@ -99,6 +99,8 @@ warnings.filterwarnings('ignore', ".*Using or importing the ABCs from 'collectio
 # more 3.7 warning from moto
 warnings.filterwarnings('ignore', r".*Use 'list\(elem\)' or iteration over elem instead.*",
                         DeprecationWarning)
+warnings.filterwarnings('ignore', r".*distutils Version classes are deprecated.*",
+                        DeprecationWarning)
 
 # ignore ResourceWarnings for unclosed sockets for the pg8000 driver on Python 3+ (tech debt: #4508)
 if sys.version_info[0] >= 3 and "pg8000" in os.getenv("BUILDBOT_TEST_DB_URL", ""):
@@ -128,3 +130,16 @@ warnings.filterwarnings('ignore', ".*Not importing directory .*/sphinxcontrib: m
 # https://github.com/pypa/setuptools/issues/2086
 warnings.filterwarnings('ignore', ".*lib2to3 package is deprecated",
                         category=PendingDeprecationWarning)
+
+# on python 3.9, this warning is generated by the stdlib
+warnings.filterwarnings('ignore', ".*The loop argument is deprecated since Python",
+                        category=DeprecationWarning)
+
+# This warning is generated by the EC2 latent
+warnings.filterwarnings('ignore', ".*stream argument is deprecated. Use stream parameter",
+                        category=DeprecationWarning)
+
+# Botocore imports deprecated urllib3.contrib.pyopenssl for backwards compatibility that we don't
+# use. See https://github.com/boto/botocore/issues/2744
+warnings.filterwarnings('ignore', ".*'urllib3.contrib.pyopenssl' module is deprecated",
+                        category=DeprecationWarning)
