@@ -25,42 +25,6 @@ from buildbot.test.fake import fakemaster
 from buildbot.worker import base
 
 
-class FakeBuildStatus(properties.PropertiesMixin):
-
-    def __init__(self):
-        self.properties = properties.Properties()
-
-    def getProperties(self):
-        return self.properties
-
-    def getInterestedUsers(self):
-        return []
-
-    def setWorkername(self, _):
-        pass
-
-    def setSourceStamps(self, _):
-        pass
-
-    def setReason(self, _):
-        pass
-
-    def setBlamelist(self, _):
-        pass
-
-    def buildStarted(self, _):
-        return True
-
-    setText = mock.Mock()
-    setText2 = mock.Mock()
-    setResults = mock.Mock()
-
-    def buildFinished(self):
-        pass
-
-    getBuilder = mock.Mock()
-
-
 class FakeWorkerStatus(properties.PropertiesMixin):
 
     def __init__(self, name):
@@ -72,12 +36,12 @@ class FakeWorkerStatus(properties.PropertiesMixin):
 class FakeBuild(properties.PropertiesMixin):
 
     def __init__(self, props=None, master=None):
-        self.build_status = FakeBuildStatus()
-        self.builder = fakemaster.FakeBuilderStatus(master)
+        self.builder = fakemaster.FakeBuilder(master)
         self.workerforbuilder = mock.Mock(
             spec=workerforbuilder.WorkerForBuilder)
         self.workerforbuilder.worker = mock.Mock(spec=base.Worker)
-        self.workerforbuilder.worker.worker_status = FakeWorkerStatus("mock")
+        self.workerforbuilder.worker.info = properties.Properties()
+        self.workerforbuilder.worker.workername = 'workername'
         self.builder.config = config.BuilderConfig(
             name='bldr',
             workernames=['a'],
@@ -92,16 +56,12 @@ class FakeBuild(properties.PropertiesMixin):
         if props is None:
             props = properties.Properties()
         props.build = self
-        self.build_status.properties = props
+        self.properties = props
         self.master = None
         self.config_version = 0
 
     def getProperties(self):
-        return self.build_status.getProperties()
-
-    @property
-    def properties(self):
-        return self.getProperties()
+        return self.properties
 
     def getSourceStamp(self, codebase):
         if codebase in self.sources:
@@ -127,7 +87,7 @@ class FakeBuild(properties.PropertiesMixin):
         return self.builder
 
     def getWorkerInfo(self):
-        return self.workerforbuilder.worker.worker_status.info
+        return self.workerforbuilder.worker.info
 
     def setUniqueStepName(self, step):
         pass
